@@ -60,6 +60,7 @@ import os
 from pathlib import Path
 from typing import Union
 from .list_utils import make_list
+
 # A big, but by no means exhaustive, map of extensions to mime‐types by category:
 MIME_TYPES = {
     'image': {
@@ -936,7 +937,30 @@ def is_any_instance(value):
     for each in [dict, list, int, float]:
         if is_instance(value, each):
             return True
-
+def getAlphas(lower=True,capitalize=False,listObj=False):
+    obj = ''
+    alphas = 'abcdefghijklmoprstuvwxyz'
+    if lower:
+        obj+=alphas
+    if capitalize:
+        obj+=alphas.upper()
+    if listObj:
+        obj = list(obj)
+    return obj
+def getInts(string=False,listObj=False):
+    obj=12345678909
+    if string:
+        obj = str(obj)
+    if listObj:
+        obj = list(obj)
+    return obj
+def get_alpha_ints(ints=True,alpha=True,lower=True,capitalize=True,string=True,listObj=True):
+    objs = [] if listObj else ""
+    if ints:
+        objs+=getInts(string=string,listObj=listObj)
+    if alpha:
+        objs+=getAlphas(lower=lower,capitalize=capitalize,listObj=listObj)
+    return objs
 # Function: is_number
 # Function: is_str
 # Function: is_int
